@@ -29,19 +29,11 @@ from airflow import AirflowException
 from airflow.configuration import conf
 from airflow.models import Connection
 from airflow.providers.common.sql.hooks.sql import DbApiHook
-from airflow.utils.operator_helpers import AIRFLOW_VAR_NAME_FORMAT_MAPPING
-
-try:
-    from airflow.utils.operator_helpers import DEFAULT_FORMAT_PREFIX
-except ImportError:
-    # This is from airflow.utils.operator_helpers,
-    # For the sake of provider backward compatibility, this is hardcoded if import fails
-    # https://github.com/apache/airflow/pull/22416#issuecomment-1075531290
-    DEFAULT_FORMAT_PREFIX = "airflow.ctx."
+from airflow.utils.operator_helpers import AIRFLOW_VAR_NAME_FORMAT_MAPPING, DEFAULT_FORMAT_PREFIX
 
 
 def generate_presto_client_info() -> str:
-    """Return json string with dag_id, task_id, execution_date and try_number"""
+    """Return json string with dag_id, task_id, execution_date and try_number."""
     context_var = {
         format_map["default"].replace(DEFAULT_FORMAT_PREFIX, ""): os.environ.get(
             format_map["env_var_format"], ""
@@ -60,7 +52,7 @@ def generate_presto_client_info() -> str:
 
 
 class PrestoException(Exception):
-    """Presto exception"""
+    """Presto exception."""
 
 
 def _boolify(value):
@@ -91,7 +83,7 @@ class PrestoHook(DbApiHook):
     placeholder = "?"
 
     def get_conn(self) -> Connection:
-        """Returns a connection object"""
+        """Returns a connection object."""
         db = self.get_connection(self.presto_conn_id)  # type: ignore[attr-defined]
         extra = db.extra_dejson
         auth = None
@@ -136,7 +128,7 @@ class PrestoHook(DbApiHook):
         return presto_conn
 
     def get_isolation_level(self) -> Any:
-        """Returns an isolation level"""
+        """Returns an isolation level."""
         db = self.get_connection(self.presto_conn_id)  # type: ignore[attr-defined]
         isolation_level = db.extra_dejson.get("isolation_level", "AUTOCOMMIT").upper()
         return getattr(IsolationLevel, isolation_level, IsolationLevel.AUTOCOMMIT)
@@ -224,3 +216,15 @@ class PrestoHook(DbApiHook):
             commit_every = 0
 
         super().insert_rows(table, rows, target_fields, commit_every)
+
+    @staticmethod
+    def _serialize_cell(cell: Any, conn: Connection | None = None) -> Any:
+        """
+        Presto will adapt all arguments to the execute() method internally,
+        hence we return cell without any conversion.
+
+        :param cell: The cell to insert into the table
+        :param conn: The database connection
+        :return: The cell
+        """
+        return cell
